@@ -6,10 +6,9 @@ class CameraFrame(object):
     def __init__(self,
                  rawArray,
                  counter=0):
-        self._array= rawArray.astype(np.float)
+        self._array = rawArray.astype(float)
         self._counter = counter
 
-
     def __eq__(self, o):
         if self._counter != o.counter():
             return False
@@ -17,15 +16,12 @@ class CameraFrame(object):
             return False
         return True
 
-
     def __ne__(self, o):
         return not self.__eq__(o)
 
-
     def __str__(self):
         return "frame-%d" % self._counter
 
-
     @staticmethod
     def fromNumpyArray(frameAsNumpyArray,
                        counter=0):
@@ -33,14 +29,11 @@ class CameraFrame(object):
             frameAsNumpyArray,
             counter)
 
-
     def toNumpyArray(self):
         return self._array
 
-
     def counter(self):
         return self._counter
 
-
     def setCounter(self, counter):
         self._counter = counter
